Learn R Programming

mldr.datasets (version 0.3.1)

birds: Dataset with sounds produced by birds and the species they belong to

Description

Multilabel dataset from the sound domain.

Usage

birds

Arguments

format

An mldr object with 645 instances, 260 attributes and 19 labels

source

Briggs, F. and Lakshminarayanan, B. and Neal, L. and Fern, X. Z. and Raich, R. and Hadley, S. J. K. and Hadley, A. S. and Betts, M. G., "Acoustic classification of multiple simultaneous bird species: A multi-instance multi-label approach", The Journal of the Acoustical Society of America, (6)131, pp. 4640--4650, 2012

Examples

Run this code
toBibtex(birds)
birds$measures

Run the code above in your browser using DataLab