Learn R Programming

mldr.datasets (version 0.3.1)

cal500: Dataset with music data along with labels for emotions, instruments, genres, etc.

Description

Multilabel dataset from the music domain.

Usage

cal500

Arguments

format

An mldr object with 502 instances, 68 attributes and 174 labels

source

Turnbull, Douglas and Barrington, Luke and Torres, David and Lanckriet, Gert, "Semantic annotation and retrieval of music and sound effects", Audio, Speech, and Language Processing, IEEE Transactions on, (2)16, pp. 467-476, 2008

Examples

Run this code
toBibtex(cal500)
cal500$measures

Run the code above in your browser using DataLab