Learn R Programming

mldr.datasets (version 0.3.1)

check_n_load.mldr: Check if an mldr object is locally available and download it if needed

Description

This function checks if the mldr object whose name is given as input is locally available, loading it in memory. If necessary, the dataset will be downloaded from the GitHub repository and saved locally.

Usage

check_n_load.mldr(mldr.name)

Arguments

mldr.name
Name of the dataset to load

Examples

Run this code
library(mldr.datasets)
check_n_load.mldr("bibtex")
bibtex$measures

Run the code above in your browser using DataLab